# vcs-realtime-sdk

## Usage

### Step 1: Generate API key

You need to contact a system administrator to create an API KEY (`x-vcs-token`) to be used by the application server to create rooms.

### Step 2: Create room

The application server creates a room via `POST /room` using the API key from step 1. The returned room token is then passed to the clients to connect to that room.

``` bash
$ curl -X POST https://<vcs-domain>/api/realtime/room \
 -H "x-vcs-token: e30b0e4e..." \
 -H "Content-Type: application/json" \
 -d '{"name":"Room A","description":"My room description"}'
```

```json
{
  "room" : {
    "id" : "b4a8b6e0-c3b6-4d70-9414-7b02adc50f71",
    "name" : "Room A",
    "description" : "My room description",
    "creationTime" : "2021-02-27T19:10:29.301Z",
    "modificationTime" : "2021-02-27T19:10:29.301Z",
    "maxParticipants" : 4,
    "roomTokenTTLSeconds" : 3600,
    "roomTTLSeconds" : 3600,
    "endpointTTLSeconds" : 3600
  },
  "token" : "49bd3a21..."
}
```

### Step 3: Connect to room via SDK

#### JS SDK

```javascript
import { joinRoom } from 'vcs-realtime-sdk';

joinRoom('49bd3a21...').then(room => {
    console.log(`Joined ${room.name} (${room.remoteParticipants.length} participants)`);
    room.on('participantJoined', participant => {
        // attach participant.stream to video tag
        // or use participant.attach
    });
    room.on('participantLeft', participant => {
        // remove participant.stream from video tag
    });
});
```
